@@ -10,7 +10,7 @@ from .base import Base
 from .document import Document, AttachmentDocument, extract_document_id_and_rev, SecurityDocument, \
     SecurityDocumentElement
 from .exceptions import CouchDBError, NameComplianceError
-from .utils import validate_db_name, DEFAULT_TIMEOUT, partitioned_db_resource_parser
+from .utils import validate_db_name, DEFAULT_TIMEOUT, partitioned_db_resource_parser, rm_nones_from_dict
 from .view import ViewResult
 
 
@@ -417,7 +417,7 @@ class Database(Base):
         update: bool
             Whether to update the index prior to returning the result. Default is `True`.
         stable : bool
-            Whether or not the view results should be returned from a “stable” set of shards. Default is `None`.
+            Whether the view results should be returned from a “stable” set of shards. Default is `None`.
         execution_stats : bool
             Include [execution statistics](https://docs.couchdb.org/en/main/api/database/find.html#find-statistics) in
             the query response. Default is `False`.
@@ -438,7 +438,7 @@ class Database(Base):
         """
         return self._post(
             resource="_explain",
-            body={
+            body=rm_nones_from_dict({
                 "selector": selector,
                 "limit": limit,
                 "skip": skip,
@@ -451,7 +451,7 @@ class Database(Base):
                 "update": update,
                 "stable": stable,
                 "execution_stats": execution_stats,
-            }
+            }),
         ).json()
 
     def find(
@@ -508,7 +508,7 @@ class Database(Base):
         update: bool
             Whether to update the index prior to returning the result. Default is `True`.
         stable : bool
-            Whether or not the view results should be returned from a “stable” set of shards. Default is `None`.
+            Whether the view results should be returned from a “stable” set of shards. Default is `None`.
         execution_stats : bool
             Include [execution statistics](https://docs.couchdb.org/en/main/api/database/find.html#find-statistics) in
             the query response. Default is `False`.
@@ -528,7 +528,7 @@ class Database(Base):
                 resource="_find",
                 partition=partition,
             ),
-            body={
+            body=rm_nones_from_dict({
                 "selector": selector,
                 "limit": limit,
                 "skip": skip,
@@ -541,7 +541,7 @@ class Database(Base):
                 "update": update,
                 "stable": stable,
                 "execution_stats": execution_stats,
-            }
+            }),
         ).json()
 
     def indexes(
@@ -670,12 +670,14 @@ class Database(Base):
             f"{docid}/{attname}",
             query_kwargs={"rev": rev}
         )
+        content_md5 = response.headers.get("content-md5")
+        digest_value = f"md5-{content_md5}" if content_md5 else None
         return AttachmentDocument(
             content=response.content,
             content_encoding=response.headers.get("content-encoding"),
             content_length=response.headers.get("content-length"),
             content_type=response.headers.get("content-type"),
-            digest="md5-" + response.headers.get("content-md5"),
+            digest=digest_value,
         )
 
     def get_design(
@@ -839,7 +841,7 @@ class Database(Base):
                 "partitioned": partitioned
             })
         return self.save(
-            doc={
+            doc=rm_nones_from_dict({
                 "_id": f"_design/{ddoc}",
                 "_rev": rev,
                 "language": language,
@@ -848,8 +850,8 @@ class Database(Base):
                 "updates": updates,
                 "validate_doc_update": validate_doc_update,
                 "views": views,
-                "autoupdate": autoupdate
-            },
+                "autoupdate": autoupdate,
+            }),
             **kwargs
         )
 
@@ -937,13 +939,13 @@ class Database(Base):
         """
         data = self._post(
             resource="_index",
-            body={
+            body=rm_nones_from_dict({
                 "index": index,
                 "ddoc": ddoc,
                 "name": name,
                 "type": index_type,
                 "partitioned": partitioned
-            }
+            }),
         ).json()
         return data["result"], data["id"], data["name"]
 
@@ -1089,6 +1091,23 @@ class Database(Base):
         Returns
         -------
         `view.ViewResult`
+
+        Examples
+        --------
+        >>> import couchdb3
+        >>> db = couchdb3.Server("http://localhost:5984").get("mydb")
+        >>> db.view("myddoc", "myview")
+        ViewResult: {
+            'total_rows': 1,
+            'offset': 0,
+            'rows': [
+                {
+                    'id': 'doc-test-view',
+                    'key': 'doc-test-view',
+                    'value': None
+                }
+            ]
+        }
         """
         path = partitioned_db_resource_parser(
             resource="_design",
